<?php
/**
 * Plugin Name: LifeLine - Blank
 * Description: Use shortcodes here.
 * Version: 1.0
 */

add_action( 'widgets_init', 'blank_load_widget' );

function blank_load_widget() {
	register_widget( 'Lifeline_Blank' );
}

class Lifeline_Blank extends WP_Widget {

	function Lifeline_Blank() {
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => '', 'description' => __('Use shortcodes here.', 'lifeline') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 500, 'height' => 350, 'id_base' => 'lifeline-blank-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'lifeline-blank-widget', __('LL - Blank', 'lifeline'), $widget_ops, $control_ops );
		
	}

	function widget( $args, $instance ) {
		
		extract( $args );

		/* Our variables from the widget settings. */		
		$title = $instance['title'];
		$content = $instance['content'];
		
		if($instance['separator'] == 'invisible'){ 
			$separator = '[separator]';
		}else if($instance['separator'] == 'line'){ 
			$separator = '[separator line="yes"]';
		}else{
			$separator = '';
		}
		
		echo do_shortcode($content);
		echo do_shortcode($separator);
		
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['content'] = $new_instance['content'];
		$instance['separator'] = strip_tags($new_instance['separator']);

		return $instance;
	}

	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'content' => '', 'title' => '', 'separator' => 'invisible');
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget settings output -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><strong>-<?php _e('Title', 'lifeline'); ?>-</strong></label><br />
			<small>This is for your own use. It shows only above in the title of the widget to help you organize easier.</small>
		</p>
		<p>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'content' ); ?>"><strong>-<?php _e('Content', 'lifeline'); ?>-</strong></label><br />
			<small>You can use HTML and shortcodes here.</small>
		</p>
		<p>
			<textarea id="<?php echo $this->get_field_id( 'content' ); ?>" name="<?php echo $this->get_field_name( 'content' ); ?>" class="widefat" rows="16" style="width:500px;"><?php echo $instance['content']; ?></textarea>
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'separator' ); ?>"><strong>-<?php _e('Separator:', 'lifeline'); ?>-</strong></label><br />
			<small>Separator clears float and makes room between content sections. If you don't want it choose "Dont' separate"</small>
		</p>
		
		<p>
			<select id="<?php echo $this->get_field_id( 'separator' ); ?>" name="<?php echo $this->get_field_name( 'separator' ); ?>" class="widefat" style="width:100%;">
				<option value="invisible" <?php if ( 'invisible' == $instance['separator'] ) echo 'selected="selected"'; ?>>Invisibile</option>
				<option value="line" <?php if ( 'line' == $instance['separator'] ) echo 'selected="selected"'; ?>>Line</option>
				<option value="no" <?php if ( 'no' == $instance['separator'] ) echo 'selected="selected"'; ?>>Don't separate</option>
			</select>
		</p>
		
	<?php
	}
}

?>