<?php
/**
 * Plugin Name: LifeLine - Columns
 * Description: Displaying columns.
 * Version: 1.0
 */

add_action( 'widgets_init', 'columns_load_widget' );

function columns_load_widget() {
	register_widget( 'Lifeline_Columns' );
}

class Lifeline_Columns extends WP_Widget {

	function Lifeline_Columns() {
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'lifeline-columns', 'description' => __('Columns. Location: Sidebar', 'lifeline') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'lifeline-columns-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'lifeline-columns-widget', __('Columns', 'lifeline'), $widget_ops, $control_ops );
		
	}

	function widget( $args, $instance ) {
		
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		
	
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;

		echo do_shortcode('[featured_posts post_type='.$post_type.' amount='.$amount.' tag='.$tag.']');
		
		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['amount'] = strip_tags( $new_instance['amount'] );
		$instance['tag'] = strip_tags( $new_instance['tag'] );
		$instance['post_type'] = strip_tags( $new_instance['post_type'] );

		return $instance;
	}

	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => __('Featured', 'lifeline'), 'amount' => 5, 'post_type' => 'post', 'tag' => '');
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget settings output -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><strong>-<?php _e('Title:', 'lifeline'); ?>-</strong></label><br />
			<small>Title will show up as "heading" for the widget in the sidebar</small>
		</p>
		<p>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'post_type' ); ?>"><strong>-<?php _e('Post type:', 'lifeline'); ?>-</strong></label><br />
			<small>What do you want to show posts from, blog or portfolio?</small>
		</p>
		<p>
			<select id="<?php echo $this->get_field_id( 'post_type' ); ?>" name="<?php echo $this->get_field_name( 'post_type' ); ?>" class="widefat" style="width:100%;">
				<option value="post" <?php if ( 'post' == $instance['post_type'] ) echo 'selected="selected"'; ?>>Blog</option>
				<option value="portfoliocustom" <?php if ( 'portfoliocustom' == $instance['post_type'] ) echo 'selected="selected"'; ?>>Portfolio</option>
			</select>
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'tag' ); ?>"><strong>-<?php _e('Tag:', 'lifeline'); ?>-</strong></label><br />
			<small>Posts with which tag do you want to show.</small>
		</p>
		<p>
			<input id="<?php echo $this->get_field_id( 'tag' ); ?>" name="<?php echo $this->get_field_name( 'tag' ); ?>" value="<?php echo $instance['tag']; ?>" class="widefat" />
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'amount' ); ?>"><strong>-<?php _e('Amount:', 'lifeline'); ?>-</strong></label><br />
			<small>How many posts to show</small>
		</p>
		<p>
			<select id="<?php echo $this->get_field_id( 'amount' ); ?>" name="<?php echo $this->get_field_name( 'amount' ); ?>" class="widefat" style="width:100%;">
				<?php
				for ($i = 1; $i <= 15; $i++) {
					?><option <?php if ( $i == $instance['amount'] ) echo 'selected="selected"'; ?>><?php echo $i; ?></option><?php
				}
				?>
			</select>
		</p>
		
	<?php
	}
}

?>