<?php
/**
 * Plugin Name: LifeLine - Popular Posts, Recent Posts, Comments
 * Description: Displaying popular posts, recent posts and comments in tabs.
 * Version: 1.0
 */

add_action( 'widgets_init', 'popular_recent_comments_load_widget' );

function popular_recent_comments_load_widget() {
	register_widget( 'Lifeline_Recent_Popular_And_Comments' );
}

class Lifeline_Recent_Popular_And_Comments extends WP_Widget {

	function Lifeline_Recent_Popular_And_Comments() {
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'lifeline-popular-recent-comments', 'description' => __('Show popular posts, latest posts and latest comments from the blog. Location: Sidebar', 'lifeline') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'lifeline-popular-recent-comments-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'lifeline-popular-recent-comments-widget', __('LL - Popular/Latest/Comments', 'lifeline'), $widget_ops, $control_ops );
		
	}

	function widget( $args, $instance ) {
		
		extract( $args );

		/* Our variables from the widget settings. */
		$amount = $instance['amount'];
	
		/* Before widget (defined by themes). */
		echo $before_widget;

		?>
		<div id="tabs">
			<ul>
				<li><a href="#tabs-1">Popular</a></li>
				<li><a href="#tabs-2">Latest</a></li>
				<li><a href="#tabs-3">Comments</a></li>
			</ul>
			<div id="tabs-1">
				<div class="latest blog posts">
					<ul>
						<?php
						
						/* Display Posts */
						$q_args=array(
						   'post_type' => 'post',
						   'showposts' => $instance['amount'],
						   'orderby' => 'comment_count',
						);
						$popular_posts_query = new WP_query();
						$popular_posts_query->query($q_args);
						
						if ($popular_posts_query->have_posts()) : while ($popular_posts_query->have_posts()) : $popular_posts_query->the_post();
						
						?>
						
							<li>
								<?php if(has_post_thumbnail()){ ?>
								<div class="img"><?php the_post_thumbnail('tiny'); ?></div>
								<?php } ?>
								<div class="content">
									<h6><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h6>
									<span class="date"><?php the_time('F j, Y'); ?></span>
								</div>
							</li>
						
						<?php
						
						endwhile; endif;
						wp_reset_query();
						
						?>
						
					</ul>
				</div> <!-- end latest blog posts -->
			</div> <!-- end tab 1 -->
			<div id="tabs-2">
				<div class="latest blog posts">
					<ul>
						<?php
						
						/* Display Posts */
						$q_args=array(
						   'post_type' => 'post',
						   'showposts' => $instance['amount'],
						);
						$recent_posts_query = new WP_query();
						$recent_posts_query->query($q_args);
						
						if ($recent_posts_query->have_posts()) : while ($recent_posts_query->have_posts()) : $recent_posts_query->the_post();
						
						?>
						
							<li>
								<?php if(has_post_thumbnail()){ ?>
								<div class="img"><?php the_post_thumbnail('tiny'); ?></div>
								<?php } ?>
								<div class="content">
									<h6><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h6>
									<span class="date"><?php the_time('F j, Y'); ?></span>
								</div>
							</li>
						
						<?php
						
						endwhile; endif;
						wp_reset_query();
						
						?>
						
					</ul>
				</div> <!-- end latest blog posts -->
			</div> <!-- end tab 2 -->
			<div id="tabs-3">
				<div class="latest blog comments">
					<ul>
						<?php
						
						$q_args = array(
							'number' => $instance['amount'],
							'status' => 'approve',
							'type' => 'comment'
						);
						$comments = get_comments($q_args);
						foreach($comments as $comment) :

						?>
						
							<li>
								<div class="img"><?php echo get_avatar( $comment, 58 ); ?></div>
								<div class="content">
									<h6><a href="<?php echo $comment->comment_author_url; ?>"><?php echo $comment->comment_author; ?></a></h6>
									<span class="comment"><?php echo substr($comment->comment_content, 0, 80).'...'; ?></span>
								</div>
							</li>
						
						<?php
						
						endforeach;
						
						?>
						
					</ul>
				</div> <!-- end latest blog comments -->
			</div> <!-- end tab 3 -->
		</div> <!-- end tabs -->
		
		<div class="hr noline"></div>
		
		<?php
		
		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['amount'] = strip_tags( $new_instance['amount'] );

		return $instance;
	}

	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => __('Recent Posts', 'lifeline'), 'amount' => 5);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<p>
			<label for="<?php echo $this->get_field_id( 'amount' ); ?>"><strong>-<?php _e('Amount:', 'lifeline'); ?>-</strong></label><br />
			<small>How many posts to show</small>
		</p>
		<p>
			<select id="<?php echo $this->get_field_id( 'amount' ); ?>" name="<?php echo $this->get_field_name( 'amount' ); ?>" class="widefat" style="width:100%;">
				<?php
				for ($i = 1; $i <= 15; $i++) {
					?><option <?php if ( $i == $instance['amount'] ) echo 'selected="selected"'; ?>><?php echo $i; ?></option><?php
				}
				?>
			</select>
		</p>
		
	<?php
	}
}

?>