<?php
/**
 * Plugin Name: LifeLine - Recent Posts
 * Description: Displaying recent posts.
 * Version: 1.0
 */

add_action( 'widgets_init', 'recent_posts_load_widget' );

function recent_posts_load_widget() {
	register_widget( 'Lifeline_Recent_Posts' );
}

class Lifeline_Recent_Posts extends WP_Widget {

	function Lifeline_Recent_Posts() {
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'lifeline-recent-posts', 'description' => __('Show latest posts from blog or portfolio. Location: Anywhere', 'lifeline') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'lifeline-recent-posts-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'lifeline-recent-posts-widget', __('LL - Latest Posts', 'lifeline'), $widget_ops, $control_ops );
		
	}

	function widget( $args, $instance ) {
		
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$amount = $instance['amount'];
		$post_type = $instance['post_type'];
		$width = $instance['width'];
	
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		
		$recent_shortcode = '[recent_posts amount="'.$amount.'" post_type="'.$post_type.'" width="'.$width.'"]';
		
		switch($width){
			
			case 'one_fourth':
				$content = '[one_fourth]'.$before_title.$title.$after_title.$recent_shortcode.'[/one_fourth]';
			break;
			
			case 'one_third':
				$content = '[one_third]'.$before_title.$title.$after_title.$recent_shortcode.'[/one_third]';
			break;
			
			case 'two_third':
				$content = '[two_third]'.$before_title.$title.$after_title.$recent_shortcode.'[/two_third]';
			break;
			
			case 'one_half':
				$content = '[one_half]'.$before_title.$title.$after_title.$recent_shortcode.'[/one_half]';
			break;
			
			case 'full_width':
				$content = $before_title.$title.$after_title.$recent_shortcode;
			break;
			
		}
		
		echo do_shortcode($content);
		
		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['amount'] = strip_tags( $new_instance['amount'] );
		$instance['width'] = strip_tags( $new_instance['width'] );
		$instance['post_type'] = strip_tags( $new_instance['post_type'] );

		return $instance;
	}

	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => __('Recent Posts', 'lifeline'), 'amount' => 5, 'width' => 'one_third', 'post_type' => 'post');
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget settings output -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><strong>-<?php _e('Title:', 'lifeline'); ?>-</strong></label><br />
			<small>Title will show up as "heading" for the widget in the sidebar</small>
		</p>
		<p>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'post_type' ); ?>"><strong>-<?php _e('Post type:', 'lifeline'); ?>-</strong></label><br />
			<small>What do you want to show posts from, blog or portfolio?</small>
		</p>
		<p>
			<select id="<?php echo $this->get_field_id( 'post_type' ); ?>" name="<?php echo $this->get_field_name( 'post_type' ); ?>" class="widefat" style="width:100%;">
				<option value="post" <?php if ( 'post' == $instance['post_type'] ) echo 'selected="selected"'; ?>>Blog</option>
				<option value="portfoliocustom" <?php if ( 'portfoliocustom' == $instance['post_type'] ) echo 'selected="selected"'; ?>>Portfolio</option>
			</select>
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'amount' ); ?>"><strong>-<?php _e('Amount:', 'lifeline'); ?>-</strong></label><br />
			<small>How many posts to show</small>
		</p>
		<p>
			<select id="<?php echo $this->get_field_id( 'amount' ); ?>" name="<?php echo $this->get_field_name( 'amount' ); ?>" class="widefat" style="width:100%;">
				<?php
				for ($i = 1; $i <= 15; $i++) {
					?><option <?php if ( $i == $instance['amount'] ) echo 'selected="selected"'; ?>><?php echo $i; ?></option><?php
				}
				?>
			</select>
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>"><strong>-<?php _e('Width:', 'lifeline'); ?>-</strong></label><br />
			<small>How big should the widget be. Notice: This has no effect when the widget is used in sidebar.</small>
		</p>
		<p>
			<select id="<?php echo $this->get_field_id( 'width' ); ?>" name="<?php echo $this->get_field_name( 'width' ); ?>" class="widefat" style="width:100%;">
				<option value="one_fourth" <?php if($instance['width'] == 'one_fourth') echo 'selected="seleceted"'; ?>>1/4 - One Fourth</option>
				<option value="one_third" <?php if($instance['width'] == 'one_third') echo 'selected="seleceted"'; ?>>1/3 - One Third</option>
				<option value="two_third" <?php if($instance['width'] == 'two_third') echo 'selected="seleceted"'; ?>>2/3 - Two Thirds</option>
				<option value="one_half" <?php if($instance['width'] == 'one_half') echo 'selected="seleceted"'; ?>>1/2 - One Half</option>
				<option value="full_width" <?php if($instance['width'] == 'full_width') echo 'selected="seleceted"'; ?>>1/1 - Full</option>
			</select>
		</p>
		
	<?php
	}
}

?>