<?php
/**
 * Plugin Name: LifeLine - Big Slider
 * Description: Big slider.
 * Version: 1.0
 */

add_action( 'widgets_init', 'big_slider_load_widget' );

function big_slider_load_widget() {
	register_widget( 'Lifeline_Big_Slider' );
}

class Lifeline_Big_Slider extends WP_Widget {

	function Lifeline_Big_Slider() {
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => '', 'description' => __('Add big slider. Location: Page', 'lifeline') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 500, 'height' => 350, 'id_base' => 'lifeline-big-slider-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'lifeline-big-slider-widget', __('LL - Slider Big', 'lifeline'), $widget_ops, $control_ops );
		
	}

	function widget( $args, $instance ) {
		
		extract( $args );

		/* Our variables from the widget settings. */		
		$content = do_shortcode($instance['content']);
		
		if($instance['separator'] == 'invisible'){ 
			$separator = '[separator]';
		}else if($instance['separator'] == 'line'){ 
			$separator = '[separator line="yes"]';
		}else{
			$separator = '';
		}
		
		$atts = '';
		
		if($instance['height'] != 'auto'){ $atts .= ' height="'.$instance['height'].'"'; }
			
		$atts .= ' raw="false"';
		
		if(isset($instance['effect']) && $instance['effect'] != 'random'){ $atts .= ' effect="'.$instance['effect'].'"'; }
			
		echo do_shortcode("[big_slider ".$atts."] ".$content." [/big_slider]");
		echo do_shortcode($separator);
		
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['content'] = strip_tags( $new_instance['content'] );
		$instance['separator'] = strip_tags($new_instance['separator']);
		$instance['height'] = strip_tags($new_instance['height']);
		$instance['effect'] = strip_tags($new_instance['effect']);
		$instance['version'] = strip_tags($new_instance['version']);
		
		return $instance;
	}

	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'content' => '', 'separator' => 'invisible', 'height' => 'auto', 'effect' => 'random', 'version' => 1.0);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget settings output -->
		<div>
			<label for="<?php echo $this->get_field_id( 'content' ); ?>"><strong>-<?php _e('Images', 'lifeline'); ?>-</strong> <a href="#" class="switch-to-media-lib" style="float:right;"><small>+ insert images</small></a></label><br />
			<small>Use the link on the right to insert images from the Media library.</small>
			
			<br />
			
			<div class="slider-images">
				<ul>
					<?php
					if($instance['version'] == 1.0){
						$instance['content'] = do_shortcode($instance['content']);
						if(preg_match_all('!http://.+\.(?:jpe?g|png|gif)!Ui',$instance['content'],$matches)){
							
							$active_imgs = array();
							
							foreach ($matches[0] as $img) {
								
								$img_id = get_attachment_id_by_url($img);
								$img_details = wp_get_attachment_image_src($img_id, 'full'); 
								$thumb_src = wp_get_attachment_image_src($img_id, 'size_100x100');
								$thumb_src = $thumb_src[0];
								$active_imgs[] = $img_id;
								?>
								<li>
									<img src="<?php echo $thumb_src; ?>" alt="<?php echo $img_details[0] ?>" />
									<span class="img-size"><?php echo $img_details[1].'x'.$img_details[2]; ?></span>
									<a class="img-remove"></a>
									<input type="hidden" class="slide-link" value="" />
									<input type="hidden" class="slide-link-type" value="none" />
									<input type="hidden" class="slide-caption" value="" />
								</li>
								<?php
								
							}
							
						}
					}else if($instance['version'] == 1.1){
						
						if(preg_match_all('/\[slide.*?\].*?\[\/slide\]/',$instance['content'],$matches)){
							
							$active_imgs = array();
							
							foreach ($matches[0] as $slide) {
								
								//change the original shortcodes to the admin shortcodes
								$slide = str_replace('[slide', '[slide_in_widget', $slide);
								$slide = str_replace('[/slide]', '[/slide_in_widget]', $slide);
								
								echo do_shortcode($slide);
								
							}
							
						}
						
					}
					?>
				</ul>
			</div>
			
			<div class="slider-add-images">
				
				<p>
					<strong><small>Insert images</small></strong><br />
					<small>Bellow you can see images from your media library. Simply click images you want to add and go "back to managing" to reorder them if you want. Notice: Images that are not at least <strong>944px</strong> wide are not in the list)</small>
				</p>
			
				<?php
				$min_width = 944;
				
				global $wpdb;
				$media_images = $wpdb->get_results("SELECT * FROM $wpdb->posts WHERE post_type = 'attachment' order by ID desc");
				?>
				
				<ul>
				
				<?php
				foreach($media_images as $post){
					
					$img_details = wp_get_attachment_image_src($post->ID, 'full');
					
					//If image is big enough for the slider proceed
					if($img_details[1] >= $min_width){
					
						$thumb_src = wp_get_attachment_image_src($post->ID, 'size_100x100');
						$thumb_src = $thumb_src[0];
						
						if(!empty($active_imgs) && in_array($post->ID, $active_imgs)){ $class_attr .= ' class="added"'; } else { $class_attr = ''; }
						
						?>
						<li<?php echo $class_attr; ?>>
							<img src="<?php echo $thumb_src; ?>" alt="<?php echo $img_details[0] ?>" />
							<span class="img-size"><?php echo $img_details[1].'x'.$img_details[2]; ?></span>
							<span class="added-notice">Added</span>
						</li>
						<?php
						
					}
					
				}
				?>
				</ul>
			</div>
			
			<div class="slider-edit-image">
				
				<p>
					<strong><small>Edit image</small></strong><br />
					<small>Bellow you can set the slide link, link behaviour and tagline. Notice: You can use vimeo videos, youtube videos and images for lightbox (ex. http://vimeo.com/2693546).</small>
				</p>
				
				<div class="clear"></div>
				
				<img class="edit-image-thumb" src="" />
				
				<div class="edit-image-data">
					<p>
						<strong><small>Link behaviour</small></strong><br />
						<small>None</small> <input type="radio" name="edit_image_link_type" value="none" checked /> &nbsp;&nbsp; <small>Regular</small> <input type="radio" name="edit_image_link_type" value="regular" /> &nbsp;&nbsp; <small>Lightbox</small> <input type="radio" name="edit_image_link_type" value="lightbox" />
					</p>
					<p><strong><small style="display:block;float:left; width:55px;">Link</small></strong> <input type="text" name="edit_image_link" style="width:340px;" /></p>
					<p><strong><small style="display:block;float:left; width:55px;">Caption</small></strong> <input type="text" name="edit_image_caption" style="width:340px;" /></p>
					<p><a href="#" class="edit-image-save">Save</a> <a href="#" class="edit-image-cancel">Cancel</a></p>
				</div>
				
			</div><!-- .slider-edit-image -->
			
		</div>
		<p class="slider-textarea-container">
			<textarea id="<?php echo $this->get_field_id( 'content' ); ?>" name="<?php echo $this->get_field_name( 'content' ); ?>" class="widefat" rows="6" style="width:500px; display:none;"><?php echo $instance['content']; ?></textarea>
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'height' ); ?>"><strong>-<?php _e('Height:', 'lifeline'); ?>-</strong></label><br />
			<small>Set a specific height of the slider. Images will be resized automatically to fit. Ex. 240 (no need for "px")</small>
		</p>
		<p>
			<input id="<?php echo $this->get_field_id( 'height' ); ?>" name="<?php echo $this->get_field_name( 'height' ); ?>" value="<?php echo $instance['height']; ?>" class="widefat" />
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'effect' ); ?>"><strong>-<?php _e('Effect:', 'lifeline'); ?>-</strong></label><br />
			<small>Which effect should the animation have?</small>
		</p>
		<p>
			<select id="<?php echo $this->get_field_id( 'effect' ); ?>" name="<?php echo $this->get_field_name( 'effect' ); ?>" class="widefat" style="width:100%;">
				<option value="random" <?php if ( 'random' == $instance['effect'] ) echo 'selected="selected"'; ?>>Random</option>
				<option value="fold" <?php if ( 'fold' == $instance['effect'] ) echo 'selected="selected"'; ?>>Fold</option>
				<option value="fade" <?php if ( 'fade' == $instance['effect'] ) echo 'selected="selected"'; ?>>Fade</option>
				<option value="sliceDown" <?php if ( 'sliceDown' == $instance['effect'] ) echo 'selected="selected"'; ?>>Slice Down Right</option>
				<option value="sliceDownLeft" <?php if ( 'sliceDownLeft' == $instance['effect'] ) echo 'selected="selected"'; ?>>Slice Down Left</option>
			</select>
		</p>
		
		<br />
		
		<p>
			<label for="<?php echo $this->get_field_id( 'separator' ); ?>"><strong>-<?php _e('Separator:', 'lifeline'); ?>-</strong></label><br />
			<small>Separator clears float and makes room between content sections. If you don't want it choose "Dont' separate"</small>
		</p>
		
		<p>
			<select id="<?php echo $this->get_field_id( 'separator' ); ?>" name="<?php echo $this->get_field_name( 'separator' ); ?>" class="widefat" style="width:100%;">
				<option value="invisible" <?php if ( 'invisible' == $instance['separator'] ) echo 'selected="selected"'; ?>>Invisibile</option>
				<option value="line" <?php if ( 'line' == $instance['separator'] ) echo 'selected="selected"'; ?>>Line</option>
				<option value="no" <?php if ( 'no' == $instance['separator'] ) echo 'selected="selected"'; ?>>Don't separate</option>
			</select>
		</p>
		
		<input type="hidden" name="<?php echo $this->get_field_name( 'version' ); ?>" value="1.1" />
		
	<?php
	}
}

?>